package com.persagy.dc.dictionary.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.persagy.common.exception.BusinessException;
import com.persagy.dc.common.constant.ValidEnum;
import com.persagy.dc.dictionary.dao.ObjectTypeHistoryMapper;
import com.persagy.dc.dictionary.entity.ObjectTypeHistory;
import com.persagy.dc.dictionary.service.IObjectTypeHistoryService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 对象类型历史 实现类
 * @author Charlie Yu
 * @date 2021-06-23
 */
@Service
public class ObjectTypeHistoryServiceImpl implements IObjectTypeHistoryService {

    @Resource
    private ObjectTypeHistoryMapper dao;

    @Override
    public ObjectTypeHistory insert(ObjectTypeHistory history) {
        dao.insert(history);
        return history;
    }

    @Override
    public void copyByVersion(String srcVersion, String version) {
        dao.copyByVersion(srcVersion, version);
    }

    @Override
    public ObjectTypeHistory update(ObjectTypeHistory history) {
        dao.updateById(history);
        return history;
    }

    @Override
    public void delete(String id) {
        ObjectTypeHistory vo = dao.selectById(id);
        vo.setValid(ValidEnum.FALSE.getType());
        dao.updateById(vo);
    }

    @Override
    public void validateOnVersionDelete(String version) {
        // 查询
        LambdaQueryWrapper<ObjectTypeHistory> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.in(ObjectTypeHistory::getVersion, version);
        queryWrapper.eq(ObjectTypeHistory::getValid, ValidEnum.TRUE.getType());
        queryWrapper.isNotNull(ObjectTypeHistory::getOperator);
        Integer count = dao.selectCount(queryWrapper);
        if(count != null && count > 0) {
            throw new BusinessException("该版本有对象类型变更记录不可直接删除!");
        }
    }
}
